# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/fileservices/v1/fileservices.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/fileservices/v1/fileservices.proto\x12\x36github.com.metaprov.modelaapi.services.fileservices.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xba\x01\n\tDataBlock\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08md5_hash\x18\x03 \x01(\t\x12\x0e\n\x06tenant\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x61taProductName\x18\x05 \x01(\t\x12\x1a\n\x12\x64\x61taProductVersion\x18\x06 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x07 \x01(\t\x12\x14\n\x0cresourceType\x18\x08 \x01(\t\x12\x14\n\x0cresourceName\x18\t \x01(\t\";\n\x0cUploadResult\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12\x10\n\x08\x64uration\x18\x03 \x01(\x05\x32\xb2\x01\n\x13\x46ileServicesService\x12\x9a\x01\n\x0bUploadChunk\x12\x41.github.com.metaprov.modelaapi.services.fileservices.v1.DataBlock\x1a\x44.github.com.metaprov.modelaapi.services.fileservices.v1.UploadResult\"\x00(\x01\x42\x38Z6github.com/metaprov/modelaapi/services/fileservices/v1b\x06proto3')



_DATABLOCK = DESCRIPTOR.message_types_by_name['DataBlock']
_UPLOADRESULT = DESCRIPTOR.message_types_by_name['UploadResult']
DataBlock = _reflection.GeneratedProtocolMessageType('DataBlock', (_message.Message,), {
  'DESCRIPTOR' : _DATABLOCK,
  '__module__' : 'github.com.metaprov.modelaapi.services.fileservices.v1.fileservices_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.fileservices.v1.DataBlock)
  })
_sym_db.RegisterMessage(DataBlock)

UploadResult = _reflection.GeneratedProtocolMessageType('UploadResult', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.services.fileservices.v1.fileservices_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.fileservices.v1.UploadResult)
  })
_sym_db.RegisterMessage(UploadResult)

_FILESERVICESSERVICE = DESCRIPTOR.services_by_name['FileServicesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/fileservices/v1'
  _DATABLOCK._serialized_start=360
  _DATABLOCK._serialized_end=546
  _UPLOADRESULT._serialized_start=548
  _UPLOADRESULT._serialized_end=607
  _FILESERVICESSERVICE._serialized_start=610
  _FILESERVICESSERVICE._serialized_end=788
# @@protoc_insertion_point(module_scope)



# Author:   Tomer Sagi
#
# Copyright (C) 2020
# For license information, see LICENSE.txt

################################################################
# Imports
################################################################



import warnings
from collections import defaultdict

from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.generated_pb2 import Measurement
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2 import Model
from greykite.algo.changepoint.adalasso.changepoint_detector import ChangepointDetector
from greykite.framework.input.univariate_time_series import UnivariateTimeSeries


from modelaapi.ts import MTimeSeries

warnings.filterwarnings("ignore")

import numpy as np
import pandas as pd

from greykite.common.data_loader import DataLoader
from greykite.framework.templates.autogen.forecast_config import ForecastConfig, EvaluationMetricParam
from greykite.framework.templates.autogen.forecast_config import MetadataParam
from greykite.framework.templates.forecaster import Forecaster
from greykite.framework.templates.model_templates import ModelTemplateEnum
from greykite.framework.utils.result_summary import summarize_grid_search_results


"""
Class to encapsulate the greykite algorithm    
"""


class GreyKiteModel():

    def __init__(self,model:Model):
        self.__model:Model = model
        self.__metadata:MetadataParam = None
        self.__forecaster = None
        self.__forecast_result = None
        self.__ts:UnivariateTimeSeries = None
        self.__m_time_series:MTimeSeries = None
        self.__forecaster_model = None # stand alone model


 #   def load_manning(self) -> pd.DataFrame:
 #       dl = DataLoader()
 #       df = dl.load_peyton_manning()
 #       return df

    ###########################################################
    # Queries
    # EDA quries.
    ###########################################################

    @property
    def time_stats(self):
        # Stat on the time series metadata.
        return self.__ts.time_stats

    @property
    def value_stats(self):
        # Stat on the value
        return self.__ts.value_stats

    @property
    def freq(self):
        return self.__ts.freq

    @property
    def regressor_cols(self):
        return self.__ts.regressor_cols

    @property
    def postfit_ts(self) -> UnivariateTimeSeries:
        return self.__ts

    #######################################################
    # Plot queries
    #######################################################
    @property
    def time_series_plot(self):
        """
        Plot the time series.
        :return:
        """
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        return self.__ts.plot()

    @property
    def forecast_plot(self):
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        return self.__forecast_result.forecast.plot()

    @property
    def component_plots(self):
        return self.__forecast_result.forecast.plot_components()

    @property
    def daily_seasonality_plot(self):
        return self.__ts.plot_grouping_evaluation(
            aggregation_func=np.mean,
            aggregation_func_name="mean",
            groupby_time_feature="hour",  # hour of day
            groupby_sliding_window_size=None,
            groupby_custom_column=None,
            title=f"daily seasonality: mean of {self.__m_time_series.value_column_name}")

    @property
    def weekly_seasonality_plot(self):
        return self.__ts.plot_grouping_evaluation(
            aggregation_func=np.mean,
            aggregation_func_name="mean",
            groupby_time_feature="str_dow",  # day of week
            groupby_sliding_window_size=None,
            groupby_custom_column=None,
            title=f"weekly seasonality: mean of {self.__m_time_series.value_column_name}")

    @property
    def yearly_seasonality_plot(self):
        return self.__ts.plot_grouping_evaluation(
            aggregation_func=np.mean,
            aggregation_func_name="mean",
            groupby_time_feature="woy",  # week of year
            groupby_sliding_window_size=None,
            groupby_custom_column=None,
            title=f"yearly seasonality: mean of {self.__m_time_series.value_column_name}")

    @property
    def backtest_plot(self):
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        return self.__forecast_result.backtest.plot()


    ############################################################
    # Attribute based on the model forecast spec.
    ############################################################
    def forecaster_spec(self):
        return self.__model.spec.forecaster

    @property
    def cv_result(self):
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        grid_search = self.__forecast_result.grid_search
        cv_results = summarize_grid_search_results(
            grid_search=grid_search,
            decimals=2,
            # The below saves space in the printed output. Remove to show all available metrics and columns.
            cv_report_metrics=None,
            column_order=["rank", "mean_test", "split_test", "mean_train", "split_train", "mean_fit_time",
                          "mean_score_time", "params"])
        # Transposes to save space in the printed output
        cv_results["params"] = cv_results["params"].astype(str)
        cv_results.set_index("params", drop=True, inplace=True)
        return cv_results.transpose()

    @property
    def forecast_result(self) -> pd.DataFrame:
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        return self.__forecast_result.forecast.df

    @property
    def model_summary(self):
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        return self.__forecast_result.model[-1].summary

    @property
    def alg_name(self):
        return self.__model.spec.forecasting.predefinedTemplate

    @property
    def model_pipeline(self):
        if self.__forecast_result == None:
            raise ValueError(" invalid forecast result, please call fit")
        return self.__forecast_result.model

    @property
    def metrics(self):
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        backtest = self.__forecast_result.backtest
        backtest_eval = defaultdict(list)
        for metric, value in backtest.train_evaluation.items():
            backtest_eval[metric].append(value)
            backtest_eval[metric].append(backtest.test_evaluation[metric])
        return pd.DataFrame(backtest_eval, index=["train", "test"]).T


   #######################################################################
   # Forecast results query. You must run the forecast to get the results.
   #######################################################################
    def load(self,time_series:MTimeSeries):
        self.__m_time_series = time_series
        self.__ts = UnivariateTimeSeries()
        self.__ts.load_data(
            df=time_series.df,
            time_col=time_series.time_column_name,
            value_col=time_series.value_column_name,
            freq=time_series.freq)  # optional, but recommended if you have missing data points
        # W for weekly, D for daily, H for hourly, etc. See ``pd.date_range``

    def fit(self,coverage=0.95):
        self.__forecaster = Forecaster()  # Creates forecasts and stores the result
        template = self.__template_name_from_pbuf()
        horizon  = len(self.__m_time_series.forecast_horizon)
        metadata_param = MetadataParam(time_col=self.__m_time_series.time_column_name,
                      value_col=self.__m_time_series.value_column_name,
                      date_format=self.__m_time_series.datetime_format
                      )
        metric_param = EvaluationMetricParam(
            cv_report_metrics = "ALL"
        )

        self.__forecast_result = self.__forecaster.run_forecast_config(  # result is also stored as `forecaster.forecast_result`.
            df= self.__m_time_series.df,
            config=ForecastConfig(
                model_template=template,
                forecast_horizon=horizon,  # forecasts 365 steps ahead
                coverage=coverage,  # 95% prediction intervals
                metadata_param=metadata_param,
                evaluation_metric_param = metric_param,
            )
        )
        self.__ts = self.__forecast_result.timeseries



    def predict(self,periods):
        if self.__forecast_result == None:
            raise ValueError("invalid forecast result, please call fit")
        future_df = self.__forecast_result.timeseries.make_future_dataframe(
            periods=periods,
            include_history=False)
        return self.__forecast_result.model.predict(future_df)

    def change_points(self):
        model = ChangepointDetector()
        res = model.find_trend_changepoints(
            df=self.__m_time_series.df,  # data df
            time_col=self.__m_time_series.time_column_name,  # time column name
            value_col=self.__m_time_series.value_column_name)  # value column name
        change_point_plot =  model.plot(plot=False)
        return pd.DataFrame({"trend_changepoints": res["trend_changepoints"]}),change_point_plot  # prints a dataframe showing the result

    def detect_seasonality(self) :
        model = ChangepointDetector()
        res = model.find_seasonality_changepoints(
            df=self.__m_time_series.df,  # data df
            time_col=self.__m_time_series.time_column_name,  # time column name
            value_col=self.__m_time_series.value_column_name)  # value column name
        df = pd.DataFrame(dict([(k, pd.Series(v)) for k, v in res["seasonality_changepoints"].items()]))  # view result
        fig = model.plot(
            seasonality_change=True,  # detected seasonality change points, discussed in next section
            seasonality_change_by_component=True,
            # plot seasonality by component (daily, weekly, etc.), discussed in next section
            seasonality_estimate=True,  # plot estimated trend+seasonality, discussed in next section
            plot=False)
        return df,fig
        # one could also print res["seasonality_changepoints"] directly to view the result

    #################################################################
    # Save and load the model
    #################################################################

    def save_model(self,dirname):
        self.__forecaster.dump_forecast_result(
            dirname,
            object_name="forecaster",
            dump_design_info=True,
            overwrite_exist_dir=True)

    def load_model(self, dirname):
        self.__forecaster = Forecaster()
        self.__forecaster.load_forecast_result(dirname,load_design_info=True)
        self.__forecast_result = self.__forecaster.forecast_result


    def evaluate(self,y_test):
        """
        Test the forecaster
        :param ts:
        :param forecaster:
        :return: the result of testing the forecaster
        """

        pred_df = self.predict(len(y_test))
        y_pred = pred_df["forecast"]
        result = []
        mape_score = mape(y_test, y_pred)
        each = Measurement()
        each.metric = "mape"
        each.value = mape_score
        result.append(each)

        rmse_score = rmse(y_test, y_pred)
        each = Measurement()
        each.metric = "rmse"
        each.value = rmse_score
        result.append(each)

        mse_score = mse(y_test, y_pred)
        each = Measurement()
        each.metric = "mse"
        each.value = mse_score
        result.append(each)

        return result

    def __template_name_from_pbuf(self):
        # By default return serving site.
        if self.__model == None:
            return ModelTemplateEnum.SILVERKITE.name
        template_name = self.__model.spec.forecasting.predefinedTemplate
        if template_name == "silverkite":
            return ModelTemplateEnum.SILVERKITE.name
        if template_name == "prophet":
            return ModelTemplateEnum.PROPHET.name
        if template_name == "auto-arima":
            return ModelTemplateEnum.AUTO_ARIMA.name
        if template_name == "lag-based":
            return ModelTemplateEnum.LAG_BASED.name
        if template_name == "sk":
            return ModelTemplateEnum.SK.name
        if template_name == "two-stage":
            return ModelTemplateEnum.SILVERKITE_TWO_STAGE.name
        if template_name == "wow":
            return ModelTemplateEnum.SILVERKITE_WOW.name
        if template_name == "daily-1-config-1":
            return ModelTemplateEnum.SILVERKITE_DAILY_1_CONFIG_1.name
        if template_name == "daily-1-config-2":
            return ModelTemplateEnum.SILVERKITE_DAILY_1_CONFIG_2.name
        if template_name == "daily-1-config-3":
            return ModelTemplateEnum.SILVERKITE_DAILY_1_CONFIG_3.name
        if template_name == "daily-1":
            return ModelTemplateEnum.SILVERKITE_DAILY_1.name
        if template_name == "daily-90":
            return ModelTemplateEnum.SILVERKITE_DAILY_90.name
        if template_name == "weekly":
            return ModelTemplateEnum.SILVERKITE_WEEKLY.name
        if template_name == "monthly":
            return ModelTemplateEnum.SILVERKITE_MONTHLY.name
        if template_name == "hourly-1":
            return ModelTemplateEnum.SILVERKITE_HOURLY_1.name
        if template_name == "hourly-24":
            return ModelTemplateEnum.SILVERKITE_HOURLY_24.name
        if template_name == "hourly-168":
            return ModelTemplateEnum.SILVERKITE_HOURLY_168.name
        if template_name == "hourly-336":
            return ModelTemplateEnum.SILVERKITE_HOURLY_336.name

        raise ValueError(f"invalid template name {template_name}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelclassrun/v1/modelclassrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/modelclassrun/v1/modelclassrun.proto\x12\x37github.com.metaprov.modelaapi.services.modelclassrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x86\x02\n\x19ListModelClassRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x02 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x1aListModelClassRunsResponse\x12\x63\n\x0emodelclassruns\x18\x01 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15ModelClassRunResponse\"|\n\x1a\x43reateModelClassRunRequest\x12^\n\rmodelclassrun\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\"\x1d\n\x1b\x43reateModelClassRunResponse\"\xac\x01\n\x1aUpdateModelClassRunRequest\x12^\n\rmodelclassrun\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateModelClassRunResponse\":\n\x17GetModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n\x18GetModelClassRunResponse\x12^\n\rmodelclassrun\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelClassRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteModelClassRunResponse\"^\n\x1b\x41pproveModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"\x1e\n\x1c\x41pproveModelClassRunResponse\"[\n\x18\x44\x65nyModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"\x1b\n\x19\x44\x65nyModelClassRunResponse\"\x1c\n\x1aPauseModelClassRunResponse\"<\n\x19PauseModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bResumeModelClassRunResponse\"=\n\x1aResumeModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x41\x62ortModelClassRunResponse\"<\n\x19\x41\x62ortModelClassRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xaf\x13\n\x14ModelClassRunService\x12\xe5\x01\n\x12ListModelClassRuns\x12R.github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest\x1aS.github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/modelclassruns/{namespace}\x12\xdf\x01\n\x13\x43reateModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/modelclassruns:\x01*\x12\xe6\x01\n\x10GetModelClassRun\x12P.github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunRequest\x1aQ.github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/modelclassruns/{namespace}/{name}\x12\xa0\x02\n\x13UpdateModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunResponse\"^\x82\xd3\xe4\x93\x02X\x1aS/v1/modelclassruns/{modelclassrun.metadata.namespace}/{modelclassrun.metadata.name}:\x01*\x12\xef\x01\n\x13\x44\x65leteModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunResponse\"-\x82\xd3\xe4\x93\x02\'*%/v1/modelclassruns/{namespace}/{name}\x12\xfa\x01\n\x14\x41pproveModelClassRun\x12T.github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunRequest\x1aU.github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunResponse\"5\x82\xd3\xe4\x93\x02/\x1a-/v1/modelclassruns/{namespace}/{name}:approve\x12\xee\x01\n\x11\x44\x65nyModelClassRun\x12Q.github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunRequest\x1aR.github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunResponse\"2\x82\xd3\xe4\x93\x02,\x1a*/v1/modelclassruns/{namespace}/{name}:deny\x12\xf2\x01\n\x12\x41\x62ortModelClassRun\x12R.github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunRequest\x1aS.github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunResponse\"3\x82\xd3\xe4\x93\x02-\x1a+/v1/modelclassruns/{namespace}/{name}:abort\x12\xf2\x01\n\x12PauseModelClassRun\x12R.github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunRequest\x1aS.github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunResponse\"3\x82\xd3\xe4\x93\x02-\x1a+/v1/modelclassruns/{namespace}/{name}:pause\x12\xf6\x01\n\x13ResumeModelClassRun\x12S.github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunRequest\x1aT.github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunResponse\"4\x82\xd3\xe4\x93\x02.\x1a,/v1/modelclassruns/{namespace}/{name}:resumeB9Z7github.com/metaprov/modelaapi/services/modelclassrun/v1b\x06proto3')



_LISTMODELCLASSRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListModelClassRunsRequest']
_LISTMODELCLASSRUNSREQUEST_LABELSENTRY = _LISTMODELCLASSRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELCLASSRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelClassRunsResponse']
_MODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['ModelClassRunResponse']
_CREATEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateModelClassRunRequest']
_CREATEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelClassRunResponse']
_UPDATEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelClassRunRequest']
_UPDATEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelClassRunResponse']
_GETMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['GetModelClassRunRequest']
_GETMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetModelClassRunResponse']
_DELETEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelClassRunRequest']
_DELETEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelClassRunResponse']
_APPROVEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['ApproveModelClassRunRequest']
_APPROVEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['ApproveModelClassRunResponse']
_DENYMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['DenyModelClassRunRequest']
_DENYMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['DenyModelClassRunResponse']
_PAUSEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['PauseModelClassRunResponse']
_PAUSEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['PauseModelClassRunRequest']
_RESUMEMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['ResumeModelClassRunResponse']
_RESUMEMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['ResumeModelClassRunRequest']
_ABORTMODELCLASSRUNRESPONSE = DESCRIPTOR.message_types_by_name['AbortModelClassRunResponse']
_ABORTMODELCLASSRUNREQUEST = DESCRIPTOR.message_types_by_name['AbortModelClassRunRequest']
ListModelClassRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelClassRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELCLASSRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELCLASSRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsRequest)
  })
_sym_db.RegisterMessage(ListModelClassRunsRequest)
_sym_db.RegisterMessage(ListModelClassRunsRequest.LabelsEntry)

ListModelClassRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelClassRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCLASSRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ListModelClassRunsResponse)
  })
_sym_db.RegisterMessage(ListModelClassRunsResponse)

ModelClassRunResponse = _reflection.GeneratedProtocolMessageType('ModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ModelClassRunResponse)
  })
_sym_db.RegisterMessage(ModelClassRunResponse)

CreateModelClassRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunRequest)
  })
_sym_db.RegisterMessage(CreateModelClassRunRequest)

CreateModelClassRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.CreateModelClassRunResponse)
  })
_sym_db.RegisterMessage(CreateModelClassRunResponse)

UpdateModelClassRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelClassRunRequest)

UpdateModelClassRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.UpdateModelClassRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelClassRunResponse)

GetModelClassRunRequest = _reflection.GeneratedProtocolMessageType('GetModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunRequest)
  })
_sym_db.RegisterMessage(GetModelClassRunRequest)

GetModelClassRunResponse = _reflection.GeneratedProtocolMessageType('GetModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.GetModelClassRunResponse)
  })
_sym_db.RegisterMessage(GetModelClassRunResponse)

DeleteModelClassRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelClassRunRequest)

DeleteModelClassRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DeleteModelClassRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelClassRunResponse)

ApproveModelClassRunRequest = _reflection.GeneratedProtocolMessageType('ApproveModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunRequest)
  })
_sym_db.RegisterMessage(ApproveModelClassRunRequest)

ApproveModelClassRunResponse = _reflection.GeneratedProtocolMessageType('ApproveModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ApproveModelClassRunResponse)
  })
_sym_db.RegisterMessage(ApproveModelClassRunResponse)

DenyModelClassRunRequest = _reflection.GeneratedProtocolMessageType('DenyModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunRequest)
  })
_sym_db.RegisterMessage(DenyModelClassRunRequest)

DenyModelClassRunResponse = _reflection.GeneratedProtocolMessageType('DenyModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.DenyModelClassRunResponse)
  })
_sym_db.RegisterMessage(DenyModelClassRunResponse)

PauseModelClassRunResponse = _reflection.GeneratedProtocolMessageType('PauseModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunResponse)
  })
_sym_db.RegisterMessage(PauseModelClassRunResponse)

PauseModelClassRunRequest = _reflection.GeneratedProtocolMessageType('PauseModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.PauseModelClassRunRequest)
  })
_sym_db.RegisterMessage(PauseModelClassRunRequest)

ResumeModelClassRunResponse = _reflection.GeneratedProtocolMessageType('ResumeModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunResponse)
  })
_sym_db.RegisterMessage(ResumeModelClassRunResponse)

ResumeModelClassRunRequest = _reflection.GeneratedProtocolMessageType('ResumeModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.ResumeModelClassRunRequest)
  })
_sym_db.RegisterMessage(ResumeModelClassRunRequest)

AbortModelClassRunResponse = _reflection.GeneratedProtocolMessageType('AbortModelClassRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELCLASSRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunResponse)
  })
_sym_db.RegisterMessage(AbortModelClassRunResponse)

AbortModelClassRunRequest = _reflection.GeneratedProtocolMessageType('AbortModelClassRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELCLASSRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelclassrun.v1.modelclassrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelclassrun.v1.AbortModelClassRunRequest)
  })
_sym_db.RegisterMessage(AbortModelClassRunRequest)

_MODELCLASSRUNSERVICE = DESCRIPTOR.services_by_name['ModelClassRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/modelclassrun/v1'
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._options = None
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELCLASSRUNSERVICE.methods_by_name['ListModelClassRuns']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['ListModelClassRuns']._serialized_options = b'\202\323\344\223\002 \022\036/v1/modelclassruns/{namespace}'
  _MODELCLASSRUNSERVICE.methods_by_name['CreateModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['CreateModelClassRun']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/modelclassruns:\001*'
  _MODELCLASSRUNSERVICE.methods_by_name['GetModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['GetModelClassRun']._serialized_options = b'\202\323\344\223\002\'\022%/v1/modelclassruns/{namespace}/{name}'
  _MODELCLASSRUNSERVICE.methods_by_name['UpdateModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['UpdateModelClassRun']._serialized_options = b'\202\323\344\223\002X\032S/v1/modelclassruns/{modelclassrun.metadata.namespace}/{modelclassrun.metadata.name}:\001*'
  _MODELCLASSRUNSERVICE.methods_by_name['DeleteModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['DeleteModelClassRun']._serialized_options = b'\202\323\344\223\002\'*%/v1/modelclassruns/{namespace}/{name}'
  _MODELCLASSRUNSERVICE.methods_by_name['ApproveModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['ApproveModelClassRun']._serialized_options = b'\202\323\344\223\002/\032-/v1/modelclassruns/{namespace}/{name}:approve'
  _MODELCLASSRUNSERVICE.methods_by_name['DenyModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['DenyModelClassRun']._serialized_options = b'\202\323\344\223\002,\032*/v1/modelclassruns/{namespace}/{name}:deny'
  _MODELCLASSRUNSERVICE.methods_by_name['AbortModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['AbortModelClassRun']._serialized_options = b'\202\323\344\223\002-\032+/v1/modelclassruns/{namespace}/{name}:abort'
  _MODELCLASSRUNSERVICE.methods_by_name['PauseModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['PauseModelClassRun']._serialized_options = b'\202\323\344\223\002-\032+/v1/modelclassruns/{namespace}/{name}:pause'
  _MODELCLASSRUNSERVICE.methods_by_name['ResumeModelClassRun']._options = None
  _MODELCLASSRUNSERVICE.methods_by_name['ResumeModelClassRun']._serialized_options = b'\202\323\344\223\002.\032,/v1/modelclassruns/{namespace}/{name}:resume'
  _LISTMODELCLASSRUNSREQUEST._serialized_start=275
  _LISTMODELCLASSRUNSREQUEST._serialized_end=537
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._serialized_start=492
  _LISTMODELCLASSRUNSREQUEST_LABELSENTRY._serialized_end=537
  _LISTMODELCLASSRUNSRESPONSE._serialized_start=540
  _LISTMODELCLASSRUNSRESPONSE._serialized_end=694
  _MODELCLASSRUNRESPONSE._serialized_start=696
  _MODELCLASSRUNRESPONSE._serialized_end=719
  _CREATEMODELCLASSRUNREQUEST._serialized_start=721
  _CREATEMODELCLASSRUNREQUEST._serialized_end=845
  _CREATEMODELCLASSRUNRESPONSE._serialized_start=847
  _CREATEMODELCLASSRUNRESPONSE._serialized_end=876
  _UPDATEMODELCLASSRUNREQUEST._serialized_start=879
  _UPDATEMODELCLASSRUNREQUEST._serialized_end=1051
  _UPDATEMODELCLASSRUNRESPONSE._serialized_start=1053
  _UPDATEMODELCLASSRUNRESPONSE._serialized_end=1082
  _GETMODELCLASSRUNREQUEST._serialized_start=1084
  _GETMODELCLASSRUNREQUEST._serialized_end=1142
  _GETMODELCLASSRUNRESPONSE._serialized_start=1145
  _GETMODELCLASSRUNRESPONSE._serialized_end=1281
  _DELETEMODELCLASSRUNREQUEST._serialized_start=1283
  _DELETEMODELCLASSRUNREQUEST._serialized_end=1344
  _DELETEMODELCLASSRUNRESPONSE._serialized_start=1346
  _DELETEMODELCLASSRUNRESPONSE._serialized_end=1375
  _APPROVEMODELCLASSRUNREQUEST._serialized_start=1377
  _APPROVEMODELCLASSRUNREQUEST._serialized_end=1471
  _APPROVEMODELCLASSRUNRESPONSE._serialized_start=1473
  _APPROVEMODELCLASSRUNRESPONSE._serialized_end=1503
  _DENYMODELCLASSRUNREQUEST._serialized_start=1505
  _DENYMODELCLASSRUNREQUEST._serialized_end=1596
  _DENYMODELCLASSRUNRESPONSE._serialized_start=1598
  _DENYMODELCLASSRUNRESPONSE._serialized_end=1625
  _PAUSEMODELCLASSRUNRESPONSE._serialized_start=1627
  _PAUSEMODELCLASSRUNRESPONSE._serialized_end=1655
  _PAUSEMODELCLASSRUNREQUEST._serialized_start=1657
  _PAUSEMODELCLASSRUNREQUEST._serialized_end=1717
  _RESUMEMODELCLASSRUNRESPONSE._serialized_start=1719
  _RESUMEMODELCLASSRUNRESPONSE._serialized_end=1748
  _RESUMEMODELCLASSRUNREQUEST._serialized_start=1750
  _RESUMEMODELCLASSRUNREQUEST._serialized_end=1811
  _ABORTMODELCLASSRUNRESPONSE._serialized_start=1813
  _ABORTMODELCLASSRUNRESPONSE._serialized_end=1841
  _ABORTMODELCLASSRUNREQUEST._serialized_start=1843
  _ABORTMODELCLASSRUNREQUEST._serialized_end=1903
  _MODELCLASSRUNSERVICE._serialized_start=1906
  _MODELCLASSRUNSERVICE._serialized_end=4385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/runbook/v1/runbook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/runbook/v1/runbook.proto\x12\x31github.com.metaprov.modelaapi.services.runbook.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\"\xf4\x01\n\x13ListRunBooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\n\x14ListRunBooksResponse\x12S\n\x08runbooks\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"f\n\x14\x43reateRunBookRequest\x12N\n\x07runbook\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x17\n\x15\x43reateRunBookResponse\"\x96\x01\n\x14UpdateRunBookRequest\x12N\n\x07runbook\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateRunBookResponse\"4\n\x11GetRunBookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x12GetRunBookResponse\x12N\n\x07runbook\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteRunBookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteRunBookResponse2\x98\x08\n\x0eRunBookService\x12\xc1\x01\n\x0cListRunBooks\x12\x46.github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest\x1aG.github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/runbooks/{namespace}\x12\xbb\x01\n\rCreateRunBook\x12G.github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookRequest\x1aH.github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/runbooks:\x01*\x12\xc2\x01\n\nGetRunBook\x12\x44.github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookRequest\x1a\x45.github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/runbooks/{namespace}/{name}\x12\xf0\x01\n\rUpdateRunBook\x12G.github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookRequest\x1aH.github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/runbooks/{runbook.metadata.namespace}/{runbook.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteRunBook\x12G.github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookRequest\x1aH.github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/runbooks/{namespace}/{name}B3Z1github.com/metaprov/modelaapi/services/runbook/v1b\x06proto3')



_LISTRUNBOOKSREQUEST = DESCRIPTOR.message_types_by_name['ListRunBooksRequest']
_LISTRUNBOOKSREQUEST_LABELSENTRY = _LISTRUNBOOKSREQUEST.nested_types_by_name['LabelsEntry']
_LISTRUNBOOKSRESPONSE = DESCRIPTOR.message_types_by_name['ListRunBooksResponse']
_CREATERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['CreateRunBookRequest']
_CREATERUNBOOKRESPONSE = DESCRIPTOR.message_types_by_name['CreateRunBookResponse']
_UPDATERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['UpdateRunBookRequest']
_UPDATERUNBOOKRESPONSE = DESCRIPTOR.message_types_by_name['UpdateRunBookResponse']
_GETRUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['GetRunBookRequest']
_GETRUNBOOKRESPONSE = DESCRIPTOR.message_types_by_name['GetRunBookResponse']
_DELETERUNBOOKREQUEST = DESCRIPTOR.message_types_by_name['DeleteRunBookRequest']
_DELETERUNBOOKRESPONSE = DESCRIPTOR.message_types_by_name['DeleteRunBookResponse']
ListRunBooksRequest = _reflection.GeneratedProtocolMessageType('ListRunBooksRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTRUNBOOKSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTRUNBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksRequest)
  })
_sym_db.RegisterMessage(ListRunBooksRequest)
_sym_db.RegisterMessage(ListRunBooksRequest.LabelsEntry)

ListRunBooksResponse = _reflection.GeneratedProtocolMessageType('ListRunBooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.ListRunBooksResponse)
  })
_sym_db.RegisterMessage(ListRunBooksResponse)

CreateRunBookRequest = _reflection.GeneratedProtocolMessageType('CreateRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookRequest)
  })
_sym_db.RegisterMessage(CreateRunBookRequest)

CreateRunBookResponse = _reflection.GeneratedProtocolMessageType('CreateRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.CreateRunBookResponse)
  })
_sym_db.RegisterMessage(CreateRunBookResponse)

UpdateRunBookRequest = _reflection.GeneratedProtocolMessageType('UpdateRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookRequest)
  })
_sym_db.RegisterMessage(UpdateRunBookRequest)

UpdateRunBookResponse = _reflection.GeneratedProtocolMessageType('UpdateRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.UpdateRunBookResponse)
  })
_sym_db.RegisterMessage(UpdateRunBookResponse)

GetRunBookRequest = _reflection.GeneratedProtocolMessageType('GetRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookRequest)
  })
_sym_db.RegisterMessage(GetRunBookRequest)

GetRunBookResponse = _reflection.GeneratedProtocolMessageType('GetRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.GetRunBookResponse)
  })
_sym_db.RegisterMessage(GetRunBookResponse)

DeleteRunBookRequest = _reflection.GeneratedProtocolMessageType('DeleteRunBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookRequest)
  })
_sym_db.RegisterMessage(DeleteRunBookRequest)

DeleteRunBookResponse = _reflection.GeneratedProtocolMessageType('DeleteRunBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.runbook.v1.runbook_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.runbook.v1.DeleteRunBookResponse)
  })
_sym_db.RegisterMessage(DeleteRunBookResponse)

_RUNBOOKSERVICE = DESCRIPTOR.services_by_name['RunBookService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/runbook/v1'
  _LISTRUNBOOKSREQUEST_LABELSENTRY._options = None
  _LISTRUNBOOKSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RUNBOOKSERVICE.methods_by_name['ListRunBooks']._options = None
  _RUNBOOKSERVICE.methods_by_name['ListRunBooks']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/runbooks/{namespace}'
  _RUNBOOKSERVICE.methods_by_name['CreateRunBook']._options = None
  _RUNBOOKSERVICE.methods_by_name['CreateRunBook']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/runbooks:\001*'
  _RUNBOOKSERVICE.methods_by_name['GetRunBook']._options = None
  _RUNBOOKSERVICE.methods_by_name['GetRunBook']._serialized_options = b'\202\323\344\223\002!\022\037/v1/runbooks/{namespace}/{name}'
  _RUNBOOKSERVICE.methods_by_name['UpdateRunBook']._options = None
  _RUNBOOKSERVICE.methods_by_name['UpdateRunBook']._serialized_options = b'\202\323\344\223\002F\032A/v1/runbooks/{runbook.metadata.namespace}/{runbook.metadata.name}:\001*'
  _RUNBOOKSERVICE.methods_by_name['DeleteRunBook']._options = None
  _RUNBOOKSERVICE.methods_by_name['DeleteRunBook']._serialized_options = b'\202\323\344\223\002!*\037/v1/runbooks/{namespace}/{name}'
  _LISTRUNBOOKSREQUEST._serialized_start=253
  _LISTRUNBOOKSREQUEST._serialized_end=497
  _LISTRUNBOOKSREQUEST_LABELSENTRY._serialized_start=452
  _LISTRUNBOOKSREQUEST_LABELSENTRY._serialized_end=497
  _LISTRUNBOOKSRESPONSE._serialized_start=500
  _LISTRUNBOOKSRESPONSE._serialized_end=632
  _CREATERUNBOOKREQUEST._serialized_start=634
  _CREATERUNBOOKREQUEST._serialized_end=736
  _CREATERUNBOOKRESPONSE._serialized_start=738
  _CREATERUNBOOKRESPONSE._serialized_end=761
  _UPDATERUNBOOKREQUEST._serialized_start=764
  _UPDATERUNBOOKREQUEST._serialized_end=914
  _UPDATERUNBOOKRESPONSE._serialized_start=916
  _UPDATERUNBOOKRESPONSE._serialized_end=939
  _GETRUNBOOKREQUEST._serialized_start=941
  _GETRUNBOOKREQUEST._serialized_end=993
  _GETRUNBOOKRESPONSE._serialized_start=995
  _GETRUNBOOKRESPONSE._serialized_end=1109
  _DELETERUNBOOKREQUEST._serialized_start=1111
  _DELETERUNBOOKREQUEST._serialized_end=1166
  _DELETERUNBOOKRESPONSE._serialized_start=1168
  _DELETERUNBOOKRESPONSE._serialized_end=1191
  _RUNBOOKSERVICE._serialized_start=1194
  _RUNBOOKSERVICE._serialized_end=2242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/cloudproxyd/v1/cloudproxyd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGgithub.com/metaprov/modelaapi/services/cloudproxyd/v1/cloudproxyd.proto\x12\x35github.com.metaprov.modelaapi.services.cloudproxyd.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\x11\n\x0fShutdownRequest\"\x12\n\x10ShutdownResponse\"\xe5\x02\n\x19VirtualBucketExistRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12l\n\x06secret\x18\x03 \x03(\x0b\x32\\.github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1aVirtualBucketExistResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\"\x8c\x03\n\x1eKeyExistInVirtualBucketRequest\x12\x0e\n\x06region\x18\x01 \x01(\t\x12T\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x0b\n\x03key\x18\x03 \x01(\t\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12q\n\x06secret\x18\x05 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"0\n\x1fKeyExistInVirtualBucketResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\"\x1c\n\x1a\x43loudVirtualBucketResponse\"\x84\x03\n\x13\x46ileDownloadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x66\n\x06secret\x18\x05 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.SecretEntry\x12\x0e\n\x06tenant\x18\x06 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x16\n\x14\x46ileDownloadResponse\"\xf7\x02\n\x12ListObjectsRequest\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12T\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x65\n\x06secret\x18\x04 \x03(\x0b\x32U.github.com.metaprov.modelaapi.services.cloudproxyd.v1.ListObjectsRequest.SecretEntry\x12\x0e\n\x06tenant\x18\x05 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"#\n\x13ListObjectsResponse\x12\x0c\n\x04keys\x18\x01 \x03(\t\"\xf0\x02\n\x11\x46ileUploadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\x05 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x14\n\x12\x46ileUploadResponse\"\xe7\x02\n\x1a\x43reateVirtualBucketRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12m\n\x06secret\x18\x03 \x03(\x0b\x32].github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x1d\n\x1b\x43reateVirtualBucketResponse2\xf5\t\n\x11\x43loudProxyService\x12\xa5\x01\n\x08\x44ownload\x12J.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest\x1aK.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadResponse\"\x00\x12\x9f\x01\n\x04List\x12I.github.com.metaprov.modelaapi.services.cloudproxyd.v1.ListObjectsRequest\x1aJ.github.com.metaprov.modelaapi.services.cloudproxyd.v1.ListObjectsResponse\"\x00\x12\x9f\x01\n\x06Upload\x12H.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest\x1aI.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadResponse\"\x00\x12\xca\x01\n\x17KeyExistInVirtualBucket\x12U.github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest\x1aV.github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketResponse\"\x00\x12\xbb\x01\n\x12VirtualBucketExist\x12P.github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest\x1aQ.github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistResponse\"\x00\x12\xc8\x01\n\x1d\x43reateVirtualBucketIfNotExist\x12Q.github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest\x1aR.github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketResponse\"\x00\x12\x9d\x01\n\x08Shutdown\x12\x46.github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownRequest\x1aG.github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownResponse\"\x00\x42\x37Z5github.com/metaprov/modelaapi/services/cloudproxyd/v1b\x06proto3')



_SHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['ShutdownRequest']
_SHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['ShutdownResponse']
_VIRTUALBUCKETEXISTREQUEST = DESCRIPTOR.message_types_by_name['VirtualBucketExistRequest']
_VIRTUALBUCKETEXISTREQUEST_SECRETENTRY = _VIRTUALBUCKETEXISTREQUEST.nested_types_by_name['SecretEntry']
_VIRTUALBUCKETEXISTRESPONSE = DESCRIPTOR.message_types_by_name['VirtualBucketExistResponse']
_KEYEXISTINVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['KeyExistInVirtualBucketRequest']
_KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY = _KEYEXISTINVIRTUALBUCKETREQUEST.nested_types_by_name['SecretEntry']
_KEYEXISTINVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['KeyExistInVirtualBucketResponse']
_CLOUDVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['CloudVirtualBucketResponse']
_FILEDOWNLOADREQUEST = DESCRIPTOR.message_types_by_name['FileDownloadRequest']
_FILEDOWNLOADREQUEST_SECRETENTRY = _FILEDOWNLOADREQUEST.nested_types_by_name['SecretEntry']
_FILEDOWNLOADRESPONSE = DESCRIPTOR.message_types_by_name['FileDownloadResponse']
_LISTOBJECTSREQUEST = DESCRIPTOR.message_types_by_name['ListObjectsRequest']
_LISTOBJECTSREQUEST_SECRETENTRY = _LISTOBJECTSREQUEST.nested_types_by_name['SecretEntry']
_LISTOBJECTSRESPONSE = DESCRIPTOR.message_types_by_name['ListObjectsResponse']
_FILEUPLOADREQUEST = DESCRIPTOR.message_types_by_name['FileUploadRequest']
_FILEUPLOADREQUEST_SECRETENTRY = _FILEUPLOADREQUEST.nested_types_by_name['SecretEntry']
_FILEUPLOADRESPONSE = DESCRIPTOR.message_types_by_name['FileUploadResponse']
_CREATEVIRTUALBUCKETREQUEST = DESCRIPTOR.message_types_by_name['CreateVirtualBucketRequest']
_CREATEVIRTUALBUCKETREQUEST_SECRETENTRY = _CREATEVIRTUALBUCKETREQUEST.nested_types_by_name['SecretEntry']
_CREATEVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['CreateVirtualBucketResponse']
ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

VirtualBucketExistRequest = _reflection.GeneratedProtocolMessageType('VirtualBucketExistRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _VIRTUALBUCKETEXISTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _VIRTUALBUCKETEXISTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest)
  })
_sym_db.RegisterMessage(VirtualBucketExistRequest)
_sym_db.RegisterMessage(VirtualBucketExistRequest.SecretEntry)

VirtualBucketExistResponse = _reflection.GeneratedProtocolMessageType('VirtualBucketExistResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALBUCKETEXISTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistResponse)
  })
_sym_db.RegisterMessage(VirtualBucketExistResponse)

KeyExistInVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('KeyExistInVirtualBucketRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _KEYEXISTINVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest)
  })
_sym_db.RegisterMessage(KeyExistInVirtualBucketRequest)
_sym_db.RegisterMessage(KeyExistInVirtualBucketRequest.SecretEntry)

KeyExistInVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('KeyExistInVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _KEYEXISTINVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketResponse)
  })
_sym_db.RegisterMessage(KeyExistInVirtualBucketResponse)

CloudVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('CloudVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudVirtualBucketResponse)
  })
_sym_db.RegisterMessage(CloudVirtualBucketResponse)

FileDownloadRequest = _reflection.GeneratedProtocolMessageType('FileDownloadRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILEDOWNLOADREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _FILEDOWNLOADREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest)
  })
_sym_db.RegisterMessage(FileDownloadRequest)
_sym_db.RegisterMessage(FileDownloadRequest.SecretEntry)

FileDownloadResponse = _reflection.GeneratedProtocolMessageType('FileDownloadResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILEDOWNLOADRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadResponse)
  })
_sym_db.RegisterMessage(FileDownloadResponse)

ListObjectsRequest = _reflection.GeneratedProtocolMessageType('ListObjectsRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTOBJECTSREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.ListObjectsRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _LISTOBJECTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.ListObjectsRequest)
  })
_sym_db.RegisterMessage(ListObjectsRequest)
_sym_db.RegisterMessage(ListObjectsRequest.SecretEntry)

ListObjectsResponse = _reflection.GeneratedProtocolMessageType('ListObjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.ListObjectsResponse)
  })
_sym_db.RegisterMessage(ListObjectsResponse)

FileUploadRequest = _reflection.GeneratedProtocolMessageType('FileUploadRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILEUPLOADREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _FILEUPLOADREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest)
  })
_sym_db.RegisterMessage(FileUploadRequest)
_sym_db.RegisterMessage(FileUploadRequest.SecretEntry)

FileUploadResponse = _reflection.GeneratedProtocolMessageType('FileUploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILEUPLOADRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadResponse)
  })
_sym_db.RegisterMessage(FileUploadResponse)

CreateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(CreateVirtualBucketRequest)
_sym_db.RegisterMessage(CreateVirtualBucketRequest.SecretEntry)

CreateVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketResponse)
  })
_sym_db.RegisterMessage(CreateVirtualBucketResponse)

_CLOUDPROXYSERVICE = DESCRIPTOR.services_by_name['CloudProxyService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/metaprov/modelaapi/services/cloudproxyd/v1'
  _VIRTUALBUCKETEXISTREQUEST_SECRETENTRY._options = None
  _VIRTUALBUCKETEXISTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY._options = None
  _KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _FILEDOWNLOADREQUEST_SECRETENTRY._options = None
  _FILEDOWNLOADREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _LISTOBJECTSREQUEST_SECRETENTRY._options = None
  _LISTOBJECTSREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _FILEUPLOADREQUEST_SECRETENTRY._options = None
  _FILEUPLOADREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEVIRTUALBUCKETREQUEST_SECRETENTRY._options = None
  _CREATEVIRTUALBUCKETREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _SHUTDOWNREQUEST._serialized_start=201
  _SHUTDOWNREQUEST._serialized_end=218
  _SHUTDOWNRESPONSE._serialized_start=220
  _SHUTDOWNRESPONSE._serialized_end=238
  _VIRTUALBUCKETEXISTREQUEST._serialized_start=241
  _VIRTUALBUCKETEXISTREQUEST._serialized_end=598
  _VIRTUALBUCKETEXISTREQUEST_SECRETENTRY._serialized_start=553
  _VIRTUALBUCKETEXISTREQUEST_SECRETENTRY._serialized_end=598
  _VIRTUALBUCKETEXISTRESPONSE._serialized_start=600
  _VIRTUALBUCKETEXISTRESPONSE._serialized_end=643
  _KEYEXISTINVIRTUALBUCKETREQUEST._serialized_start=646
  _KEYEXISTINVIRTUALBUCKETREQUEST._serialized_end=1042
  _KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY._serialized_start=553
  _KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY._serialized_end=598
  _KEYEXISTINVIRTUALBUCKETRESPONSE._serialized_start=1044
  _KEYEXISTINVIRTUALBUCKETRESPONSE._serialized_end=1092
  _CLOUDVIRTUALBUCKETRESPONSE._serialized_start=1094
  _CLOUDVIRTUALBUCKETRESPONSE._serialized_end=1122
  _FILEDOWNLOADREQUEST._serialized_start=1125
  _FILEDOWNLOADREQUEST._serialized_end=1513
  _FILEDOWNLOADREQUEST_SECRETENTRY._serialized_start=553
  _FILEDOWNLOADREQUEST_SECRETENTRY._serialized_end=598
  _FILEDOWNLOADRESPONSE._serialized_start=1515
  _FILEDOWNLOADRESPONSE._serialized_end=1537
  _LISTOBJECTSREQUEST._serialized_start=1540
  _LISTOBJECTSREQUEST._serialized_end=1915
  _LISTOBJECTSREQUEST_SECRETENTRY._serialized_start=553
  _LISTOBJECTSREQUEST_SECRETENTRY._serialized_end=598
  _LISTOBJECTSRESPONSE._serialized_start=1917
  _LISTOBJECTSRESPONSE._serialized_end=1952
  _FILEUPLOADREQUEST._serialized_start=1955
  _FILEUPLOADREQUEST._serialized_end=2323
  _FILEUPLOADREQUEST_SECRETENTRY._serialized_start=553
  _FILEUPLOADREQUEST_SECRETENTRY._serialized_end=598
  _FILEUPLOADRESPONSE._serialized_start=2325
  _FILEUPLOADRESPONSE._serialized_end=2345
  _CREATEVIRTUALBUCKETREQUEST._serialized_start=2348
  _CREATEVIRTUALBUCKETREQUEST._serialized_end=2707
  _CREATEVIRTUALBUCKETREQUEST_SECRETENTRY._serialized_start=553
  _CREATEVIRTUALBUCKETREQUEST_SECRETENTRY._serialized_end=598
  _CREATEVIRTUALBUCKETRESPONSE._serialized_start=2709
  _CREATEVIRTUALBUCKETRESPONSE._serialized_end=2738
  _CLOUDPROXYSERVICE._serialized_start=2741
  _CLOUDPROXYSERVICE._serialized_end=4010
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/reciperun/v1/reciperun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCgithub.com/metaprov/modelaapi/services/reciperun/v1/reciperun.proto\x12\x33github.com.metaprov.modelaapi.services.reciperun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xfa\x01\n\x15ListRecipeRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x02 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x16ListRecipeRunsResponse\x12W\n\nreciperuns\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"l\n\x16\x43reateRecipeRunRequest\x12R\n\treciperun\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x19\n\x17\x43reateRecipeRunResponse\"\x9c\x01\n\x16UpdateRecipeRunRequest\x12R\n\treciperun\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x19\n\x17UpdateRecipeRunResponse\"6\n\x13GetRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n\x14GetRecipeRunResponse\x12R\n\treciperun\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16\x44\x65leteRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteRecipeRunResponse2\xda\x08\n\x10RecipeRunService\x12\xcd\x01\n\x0eListRecipeRuns\x12J.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest\x1aK.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/reciperuns/{namespace}\x12\xc7\x01\n\x0f\x43reateRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/reciperuns:\x01*\x12\xce\x01\n\x0cGetRecipeRun\x12H.github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest\x1aI.github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/reciperuns/{namespace}/{name}\x12\x80\x02\n\x0fUpdateRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunResponse\"R\x82\xd3\xe4\x93\x02L\x1aG/v1/reciperuns/{reciperun.metadata.namespace}/{reciperun.metadata.name}:\x01*\x12\xd7\x01\n\x0f\x44\x65leteRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunResponse\")\x82\xd3\xe4\x93\x02#*!/v1/reciperuns/{namespace}/{name}B5Z3github.com/metaprov/modelaapi/services/reciperun/v1b\x06proto3')



_LISTRECIPERUNSREQUEST = DESCRIPTOR.message_types_by_name['ListRecipeRunsRequest']
_LISTRECIPERUNSREQUEST_LABELSENTRY = _LISTRECIPERUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTRECIPERUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListRecipeRunsResponse']
_CREATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateRecipeRunRequest']
_CREATERECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateRecipeRunResponse']
_UPDATERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateRecipeRunRequest']
_UPDATERECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateRecipeRunResponse']
_GETRECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['GetRecipeRunRequest']
_GETRECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetRecipeRunResponse']
_DELETERECIPERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteRecipeRunRequest']
_DELETERECIPERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteRecipeRunResponse']
ListRecipeRunsRequest = _reflection.GeneratedProtocolMessageType('ListRecipeRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTRECIPERUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTRECIPERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest)
  })
_sym_db.RegisterMessage(ListRecipeRunsRequest)
_sym_db.RegisterMessage(ListRecipeRunsRequest.LabelsEntry)

ListRecipeRunsResponse = _reflection.GeneratedProtocolMessageType('ListRecipeRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse)
  })
_sym_db.RegisterMessage(ListRecipeRunsResponse)

CreateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRunRequest)

CreateRecipeRunResponse = _reflection.GeneratedProtocolMessageType('CreateRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunResponse)
  })
_sym_db.RegisterMessage(CreateRecipeRunResponse)

UpdateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRunRequest)

UpdateRecipeRunResponse = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunResponse)
  })
_sym_db.RegisterMessage(UpdateRecipeRunResponse)

GetRecipeRunRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest)
  })
_sym_db.RegisterMessage(GetRecipeRunRequest)

GetRecipeRunResponse = _reflection.GeneratedProtocolMessageType('GetRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse)
  })
_sym_db.RegisterMessage(GetRecipeRunResponse)

DeleteRecipeRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRunRequest)

DeleteRecipeRunResponse = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunResponse)
  })
_sym_db.RegisterMessage(DeleteRecipeRunResponse)

_RECIPERUNSERVICE = DESCRIPTOR.services_by_name['RecipeRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/metaprov/modelaapi/services/reciperun/v1'
  _LISTRECIPERUNSREQUEST_LABELSENTRY._options = None
  _LISTRECIPERUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _RECIPERUNSERVICE.methods_by_name['ListRecipeRuns']._options = None
  _RECIPERUNSERVICE.methods_by_name['ListRecipeRuns']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/reciperuns/{namespace}'
  _RECIPERUNSERVICE.methods_by_name['CreateRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['CreateRecipeRun']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/reciperuns:\001*'
  _RECIPERUNSERVICE.methods_by_name['GetRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['GetRecipeRun']._serialized_options = b'\202\323\344\223\002#\022!/v1/reciperuns/{namespace}/{name}'
  _RECIPERUNSERVICE.methods_by_name['UpdateRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['UpdateRecipeRun']._serialized_options = b'\202\323\344\223\002L\032G/v1/reciperuns/{reciperun.metadata.namespace}/{reciperun.metadata.name}:\001*'
  _RECIPERUNSERVICE.methods_by_name['DeleteRecipeRun']._options = None
  _RECIPERUNSERVICE.methods_by_name['DeleteRecipeRun']._serialized_options = b'\202\323\344\223\002#*!/v1/reciperuns/{namespace}/{name}'
  _LISTRECIPERUNSREQUEST._serialized_start=259
  _LISTRECIPERUNSREQUEST._serialized_end=509
  _LISTRECIPERUNSREQUEST_LABELSENTRY._serialized_start=464
  _LISTRECIPERUNSREQUEST_LABELSENTRY._serialized_end=509
  _LISTRECIPERUNSRESPONSE._serialized_start=512
  _LISTRECIPERUNSRESPONSE._serialized_end=650
  _CREATERECIPERUNREQUEST._serialized_start=652
  _CREATERECIPERUNREQUEST._serialized_end=760
  _CREATERECIPERUNRESPONSE._serialized_start=762
  _CREATERECIPERUNRESPONSE._serialized_end=787
  _UPDATERECIPERUNREQUEST._serialized_start=790
  _UPDATERECIPERUNREQUEST._serialized_end=946
  _UPDATERECIPERUNRESPONSE._serialized_start=948
  _UPDATERECIPERUNRESPONSE._serialized_end=973
  _GETRECIPERUNREQUEST._serialized_start=975
  _GETRECIPERUNREQUEST._serialized_end=1029
  _GETRECIPERUNRESPONSE._serialized_start=1031
  _GETRECIPERUNRESPONSE._serialized_end=1151
  _DELETERECIPERUNREQUEST._serialized_start=1153
  _DELETERECIPERUNREQUEST._serialized_end=1210
  _DELETERECIPERUNRESPONSE._serialized_start=1212
  _DELETERECIPERUNRESPONSE._serialized_end=1237
  _RECIPERUNSERVICE._serialized_start=1240
  _RECIPERUNSERVICE._serialized_end=2354
# @@protoc_insertion_point(module_scope)
